@@ -14,11 +14,13 @@ logger.setLevel(logging.INFO)
 
 # Main imports
 from . import (
+    compat,
     math,
     flux,
     sp,
     ops,
     integrals,
+    interfaces,
     latitude,
     size,
     longitude,
@@ -28,5 +30,6 @@ from . import (
     visualize,
 )
 from .sp import StarryProcess
+from .interfaces import MCMCInterface
 from .latitude import gauss2beta, beta2gauss
 from .temporal import *
