@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
 from ..base_op import BaseOp
-from ...compat import Apply
+from ...compat import Apply, theano, tt, floatX
 from .special_tensordotRz_rev import special_tensordotRzRevOp
-import theano.tensor as tt
 
 __all__ = ["special_tensordotRzOp"]
 
@@ -17,27 +16,15 @@ class special_tensordotRzOp(BaseOp):
 
     def make_node(self, T, M, theta):
         in_args = [
-            tt.as_tensor_variable(arg).astype(tt.config.floatX)
-            for arg in [T, M, theta]
-        ]
-        out_args = [
-            tt.TensorType(
-                dtype=tt.config.floatX,
-                broadcastable=[
-                    False,
-                ],
-            )(),
+            tt.as_tensor_variable(arg).astype(floatX) for arg in [T, M, theta]
         ]
+        out_args = [tt.TensorType(dtype=floatX, broadcastable=[False])()]
         return Apply(self, in_args, out_args)
 
     def infer_shape(self, *args):
         shapes = args[-1]
         K = shapes[2][0]
-        return (
-            [
-                K,
-            ],
-        )
+        return ([K],)
 
     def grad(self, inputs, gradients):
         return [tt.zeros((self.N, self.N))] + self.grad_op(
