@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 from ..base_op import BaseOp
-from ...compat import Apply
-import theano.tensor as tt
+from ...compat import Apply, theano, tt, floatX
 
 __all__ = ["special_tensordotRzRevOp"]
 
@@ -12,28 +11,16 @@ class special_tensordotRzRevOp(BaseOp):
 
     def make_node(self, T, M, theta, bf):
         in_args = [
-            tt.as_tensor_variable(arg).astype(tt.config.floatX)
+            tt.as_tensor_variable(arg).astype(floatX)
             for arg in [T, M, theta, bf]
         ]
         out_args = [
-            tt.TensorType(
-                dtype=tt.config.floatX, broadcastable=[False, False]
-            )(),
-            tt.TensorType(
-                dtype=tt.config.floatX,
-                broadcastable=[
-                    False,
-                ],
-            )(),
+            tt.TensorType(dtype=floatX, broadcastable=[False, False])(),
+            tt.TensorType(dtype=floatX, broadcastable=[False])(),
         ]
         return Apply(self, in_args, out_args)
 
     def infer_shape(self, *args):
         shapes = args[-1]
         K = shapes[2][0]
-        return (
-            [self.N, self.N],
-            [
-                K,
-            ],
-        )
+        return ([self.N, self.N], [K])
